@@ -1,22 +1,89 @@
 # vim: set fileencoding=utf-8 :
 
-# Copyright (C) 2007, 2008 Insecure.Com LLC.
-#
-# Author: João Paulo de Souza Medeiros <ignotus21@gmail.com>
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+# ***********************IMPORTANT NMAP LICENSE TERMS************************
+# *                                                                         *
+# * The Nmap Security Scanner is (C) 1996-2011 Insecure.Com LLC. Nmap is    *
+# * also a registered trademark of Insecure.Com LLC.  This program is free  *
+# * software; you may redistribute and/or modify it under the terms of the  *
+# * GNU General Public License as published by the Free Software            *
+# * Foundation; Version 2 with the clarifications and exceptions described  *
+# * below.  This guarantees your right to use, modify, and redistribute     *
+# * this software under certain conditions.  If you wish to embed Nmap      *
+# * technology into proprietary software, we sell alternative licenses      *
+# * (contact sales@insecure.com).  Dozens of software vendors already       *
+# * license Nmap technology such as host discovery, port scanning, OS       *
+# * detection, and version detection.                                       *
+# *                                                                         *
+# * Note that the GPL places important restrictions on "derived works", yet *
+# * it does not provide a detailed definition of that term.  To avoid       *
+# * misunderstandings, we consider an application to constitute a           *
+# * "derivative work" for the purpose of this license if it does any of the *
+# * following:                                                              *
+# * o Integrates source code from Nmap                                      *
+# * o Reads or includes Nmap copyrighted data files, such as                *
+# *   nmap-os-db or nmap-service-probes.                                    *
+# * o Executes Nmap and parses the results (as opposed to typical shell or  *
+# *   execution-menu apps, which simply display raw Nmap output and so are  *
+# *   not derivative works.)                                                *
+# * o Integrates/includes/aggregates Nmap into a proprietary executable     *
+# *   installer, such as those produced by InstallShield.                   *
+# * o Links to a library or executes a program that does any of the above   *
+# *                                                                         *
+# * The term "Nmap" should be taken to also include any portions or derived *
+# * works of Nmap.  This list is not exclusive, but is meant to clarify our *
+# * interpretation of derived works with some common examples.  Our         *
+# * interpretation applies only to Nmap--we don't speak for other people's  *
+# * GPL works.                                                              *
+# *                                                                         *
+# * If you have any questions about the GPL licensing restrictions on using *
+# * Nmap in non-GPL works, we would be happy to help.  As mentioned above,  *
+# * we also offer alternative license to integrate Nmap into proprietary    *
+# * applications and appliances.  These contracts have been sold to dozens  *
+# * of software vendors, and generally include a perpetual license as well  *
+# * as providing for priority support and updates as well as helping to     *
+# * fund the continued development of Nmap technology.  Please email        *
+# * sales@insecure.com for further information.                             *
+# *                                                                         *
+# * As a special exception to the GPL terms, Insecure.Com LLC grants        *
+# * permission to link the code of this program with any version of the     *
+# * OpenSSL library which is distributed under a license identical to that  *
+# * listed in the included docs/licenses/OpenSSL.txt file, and distribute   *
+# * linked combinations including the two. You must obey the GNU GPL in all *
+# * respects for all of the code used other than OpenSSL.  If you modify    *
+# * this file, you may extend this exception to your version of the file,   *
+# * but you are not obligated to do so.                                     *
+# *                                                                         *
+# * If you received these files with a written license agreement or         *
+# * contract stating terms other than the terms above, then that            *
+# * alternative license agreement takes precedence over these comments.     *
+# *                                                                         *
+# * Source is provided to this software because we believe users have a     *
+# * right to know exactly what a program is going to do before they run it. *
+# * This also allows you to audit the software for security holes (none     *
+# * have been found so far).                                                *
+# *                                                                         *
+# * Source code also allows you to port Nmap to new platforms, fix bugs,    *
+# * and add new features.  You are highly encouraged to send your changes   *
+# * to nmap-dev@insecure.org for possible incorporation into the main       *
+# * distribution.  By sending these changes to Fyodor or one of the         *
+# * Insecure.Org development mailing lists, it is assumed that you are      *
+# * offering the Nmap Project (Insecure.Com LLC) the unlimited,             *
+# * non-exclusive right to reuse, modify, and relicense the code.  Nmap     *
+# * will always be available Open Source, but this is important because the *
+# * inability to relicense code has caused devastating problems for other   *
+# * Free Software projects (such as KDE and NASM).  We also occasionally    *
+# * relicense the code to third parties as discussed above.  If you wish to *
+# * specify special license conditions of your contributions, just say so   *
+# * when you send them.                                                     *
+# *                                                                         *
+# * This program is distributed in the hope that it will be useful, but     *
+# * WITHOUT ANY WARRANTY; without even the implied warranty of              *
+# * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
+# * General Public License v2.0 for more details at                         *
+# * http://www.gnu.org/licenses/gpl-2.0.html , or in the COPYING file       *
+# * included with Nmap.                                                     *
+# *                                                                         *
+# ***************************************************************************/
 
 import gtk
 import math
@@ -71,6 +138,12 @@ class ControlWidget(BWVBox):
         self.bw_pack_start_noexpand_nofill(self.__view)
 
 
+def try_set_tooltip_text(widget, text):
+    try:
+        widget.set_tooltip_text(text)
+    except AttributeError:
+        # The set_tooltip_text method was introduced in PyGTK 2.12.
+        pass
 
 class ControlAction(BWExpander):
     """
@@ -93,10 +166,8 @@ class ControlAction(BWExpander):
         self.__tbox.bw_set_spacing(0)
         self.__vbox = BWVBox()
 
-        self.__tooltips = gtk.Tooltips()
-
         self.__jump_to = gtk.RadioToolButton(None, gtk.STOCK_JUMP_TO)
-        self.__jump_to.set_tooltip(self.__tooltips, _('Change focus'))
+        try_set_tooltip_text(self.__jump_to, 'Change focus')
         self.__jump_to.connect('toggled',
                                self.__change_pointer,
                                POINTER_JUMP_TO)
@@ -109,20 +180,20 @@ class ControlAction(BWExpander):
             self.__info.set_label(_("Info"))
         else:
             self.__info = gtk.RadioToolButton(self.__jump_to, info_icon)
-        self.__info.set_tooltip(self.__tooltips, _('Show information'))
+        try_set_tooltip_text(self.__info, 'Show information')
         self.__info.connect('toggled',
                             self.__change_pointer,
                             POINTER_INFO)
 
         self.__group = gtk.RadioToolButton(self.__jump_to, gtk.STOCK_ADD)
-        self.__group.set_tooltip(self.__tooltips, _('Group children'))
+        try_set_tooltip_text(self.__group, 'Group children')
         self.__group.connect('toggled',
                              self.__change_pointer,
                              POINTER_GROUP)
 
         self.__region = gtk.RadioToolButton(self.__jump_to,
                                             gtk.STOCK_SELECT_COLOR)
-        self.__region.set_tooltip(self.__tooltips, _('Fill region'))
+        try_set_tooltip_text(self.__region, 'Fill region')
         self.__region.connect('toggled',
                               self.__change_pointer,
                               POINTER_FILL)
@@ -1105,7 +1176,7 @@ class ControlNavigation(gtk.DrawingArea):
             self.__rotate_node.set_coordinate(r, t)
 
             self.queue_draw()
-        
+
         return False
 
 
@@ -1186,7 +1257,7 @@ class ControlNavigation(gtk.DrawingArea):
 
             pc.set_coordinate(23, 45 * i)
             x, y = pc.to_cartesian()
-        
+
             self.context.set_dash([1,1])
             self.context.move_to(xc, yc)
             self.context.line_to(xc + x, yc - y)
@@ -1294,7 +1365,7 @@ class ControlNavigation(gtk.DrawingArea):
 
             pc.set_coordinate(23, 45 * i)
             x, y = pc.to_cartesian()
-        
+
             center = (xc + x, yc - y)
             result = geometry.is_in_circle(pointer,
                                            self.__move_radius,
